@@ -25,6 +25,7 @@ class CLI(click.Group):
             "{0} [cask] rm FORMULA...",
             "{0} [cask] list [FORMULA]",
             "{0} [cask] missing",
+            "{0} tap missing",
             "{0} set-default [-g] NAME KEY VALUE",
             "{0} remove-default [-g] NAME KEY",
             "{0} apply-defaults",
@@ -34,7 +35,7 @@ class CLI(click.Group):
             "{0} run-scripts",
             "{0} restore",
             "{0} relink",
-            "{0} addlink",
+            "{0} addlink NAME ITEM...",
             "{0} unlink"
         ]
 
@@ -118,7 +119,10 @@ def rm(cider, formulas):
 @click.argument("tap", required=False)
 @click.pass_obj
 def tap(cider, tap):
-    cider.tap(tap)
+    if tap == "missing":
+        cider.list_missing_taps()
+    else:
+        cider.tap(tap)
 
 
 @cli.command()
@@ -216,10 +220,10 @@ def run_scripts(cider):
 
 @cli.command("addlink")
 @click.argument("name")
-@click.argument("item")
+@click.argument("items", nargs=-1, required=True)
 @click.pass_obj
-def addlink(cider, name, item):
-    cider.addlink(name, item)
+def addlink(cider, name, items):
+    cider.addlink(name, *items)
 
 
 @cli.command("unlink")
