@@ -257,11 +257,22 @@ class Cider(object):
                 tty.puterr("{0} not found in bootstrap".format(formula))
 
     def tap(self, tap):
-        self.brew.tap(tap)
-        if tap is not None:
+        if tap is None:
+            tapped = self.tapped()
+            if tapped:
+                print("\n".join(tapped))
+        else:
+            self.brew.tap(tap)
+            self.add_taps([tap])
+
+    def add_taps(self, taps):
+        def transform(tap):
+            return lambda x: x + [tap] if tap not in x else x
+
+        for tap in taps:
             if self._modify_bootstrap(
                 "taps",
-                transform=lambda x: x + [tap] if tap not in x else x,
+                transform=transform(tap),
                 fallback=[]
             ):
                 tty.puts("Added {0} tap to bootstrap".format(tap))
@@ -385,6 +396,9 @@ class Cider(object):
             return [x for x in formulas if x.startswith(prefix)]
         return formulas
 
+    def tapped(self):
+        return self.read_bootstrap().get("taps", [])
+
     def missing(self):
         installed = [item.split()[0].strip() for item in self.installed()]
         brewed = self.brew.ls()
@@ -395,6 +409,11 @@ class Cider(object):
 
         return sorted(filter(brew_orphan, set(brewed) - set(installed)))
 
+    def missing_taps(self):
+        bootstrapped = self.tapped()
+        brewed = self.brew.tap().strip().splitlines()
+        return sorted(set(brewed) - set(bootstrapped))
+
     def ls(self, formula):
         formulas = self.installed(formula)
         if formulas:
@@ -411,14 +430,27 @@ class Cider(object):
             tty.puterr(fmt.format(len(missing_items), suffix), warning=True)
 
             print("\n".join(missing_items) + "\n")
-            sys.stdout.write("Add missing items to bootstrap? [y/N] ")
+            sys.stdout.write("Add to bootstrap? [y/N] ")
 
             if sys.stdin.read(1).lower() == "y":
                 self.add_to_bootstrap(missing_items)
         else:
             print("Everything up to date.")
 
-        return missing_items
+    def list_missing_taps(self):
+        missing_taps = self.missing_taps()
+        if missing_taps:
+            suffix = "s" if len(missing_taps) != 1 else ""
+            fmt = "{0} missing tap{1}"
+            tty.puterr(fmt.format(len(missing_taps), suffix), warning=True)
+
+            print("\n".join(missing_taps) + "\n")
+            sys.stdout.write("Add to bootstrap? [y/N] ")
+
+            if sys.stdin.read(1).lower() == "y":
+                self.add_taps(missing_taps)
+        else:
+            print("Everything up to date.")
 
     @staticmethod
     def json_value(value):
@@ -530,31 +562,34 @@ class Cider(object):
 
         return self._modify_bootstrap("symlinks", transform)
 
-    def addlink(self, name, path):
-        stow_path = os.path.join(self.symlink_dir, name)
-        stow_fpath = os.path.join(stow_path, os.path.basename(path))
-        if not os.path.exists(path):
-            raise StowError("Can't link {0}: No such file or directory".format(
-                collapseuser(path)
-            ))
+    def addlink(self, name, *items):
+        for item in items:
+            stow_path = os.path.join(self.symlink_dir, name)
+            stow_fpath = os.path.join(stow_path, os.path.basename(item))
+            if not os.path.exists(item):
+                raise StowError(
+                    "Can't link {0}: No such file or directory".format(
+                        collapseuser(item)
+                    )
+                )
 
-        samefile = os.path.exists(stow_fpath) and os.path.samefile(
-            os.path.realpath(stow_fpath), os.path.realpath(path)
-        )
+            samefile = os.path.exists(stow_fpath) and os.path.samefile(
+                os.path.realpath(stow_fpath), os.path.realpath(item)
+            )
 
-        if os.path.exists(stow_fpath) and not samefile:
-            raise StowError("Link already exists at {0}".format(
-                collapseuser(stow_fpath)
-            ))
+            if os.path.exists(stow_fpath) and not samefile:
+                raise StowError("Link already exists at {0}".format(
+                    collapseuser(stow_fpath)
+                ))
 
-        if not samefile:
-            mkdir_p(stow_path)
-            shutil.move(path, stow_path)
+            if not samefile:
+                mkdir_p(stow_path)
+                shutil.move(item, stow_path)
 
-        target = os.path.abspath(path)
-        self.add_symlink(name, target)
-        self.mklink(stow_fpath, target)
-        self._update_target_cache(self._cached_targets() + [target])
+            target = os.path.abspath(item)
+            self.add_symlink(name, target)
+            self.mklink(stow_fpath, target)
+            self._update_target_cache(self._cached_targets() + [target])
 
     def unlink(self, name):
         symlinks = self.read_bootstrap().get("symlinks", {})
