@@ -31,15 +31,13 @@ class BrewMissingError(CiderException):
         self.url = url
 
 
-class BootstrapMissingError(CiderException):
-    def __init__(self, message, path, exit_code=None):
-        CiderException.__init__(self, message, exit_code)
-        self.path = path
-
-
 class SymlinkError(CiderException):
     pass
 
 
 class AppMissingError(CiderException):
     pass
+
+
+class StowError(CiderException):
+    pass
